Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(477)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java

Issue 1919183003: Rename NotificationUIManager to NotificationPlatformBridge (1/2) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java b/chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java
index 5b18a474f478cab86475b72b76408ddad597aca1..8202494e484dbdb256bb499f3a9bc6a7aa4a0c31 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/notifications/NotificationService.java
@@ -67,7 +67,7 @@ public class NotificationService extends IntentService {
/**
* Initializes Chrome and starts the browser process if it's not running as of yet, and
* dispatch |intent| to the NotificationUIManager once this is done.
*
* @param intent The intent containing the notification's information.
*/
@@ -77,8 +77,8 @@ public class NotificationService extends IntentService {
ChromeBrowserInitializer.getInstance(this).handleSynchronousStartup();
// Now that the browser process is initialized, we pass forward the call to the
- // Notification UI Manager which will take care of delivering the appropriate events.
- if (!NotificationUIManager.dispatchNotificationEvent(intent)) {
+ // NotificationPlatformBridge which will take care of delivering the appropriate events.
+ if (!NotificationPlatformBridge.dispatchNotificationEvent(intent)) {
Log.w(TAG, "Unable to dispatch the notification event to Chrome.");
}
@@ -67,7 +67,7 @@ public class NotificationService extends IntentService {
/**
* Initializes Chrome and starts the browser process if it's not running as of yet, and
- * dispatch |intent| to the NotificationUIManager once this is done.
+ * dispatch |intent| to the NotificationPlatformBridge once this is done.
*
* @param intent The intent containing the notification's information.

Powered by Google App Engine
This is Rietveld 408576698